<?php

namespace Me\Teszt\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Me\Teszt\Http\Requests\Table1Request;
use Me\Teszt\Interfaces\Table1RepositoryInterface;
use Me\Teszt\Models\Table1;

/**
 * Resource controller class for table1.
 */
class Table1ResourceController extends BaseController
{

    /**
     * Initialize table1 resource controller.
     *
     * @param type Table1RepositoryInterface $table1
     *
     * @return null
     */
    public function __construct(Table1RepositoryInterface $table1)
    {
        parent::__construct();
        $this->repository = $table1;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Me\Teszt\Repositories\Criteria\Table1ResourceCriteria::class);
    }

    /**
     * Display a list of table1.
     *
     * @return Response
     */
    public function index(Table1Request $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Me\Teszt\Repositories\Presenter\Table1Presenter::class)
                ->$function();
        }

        $table1s = $this->repository->paginate();

        return $this->response->title(trans('teszt::table1.names'))
            ->view('teszt::table1.index', true)
            ->data(compact('table1s', 'view'))
            ->output();
    }

    /**
     * Display table1.
     *
     * @param Request $request
     * @param Model   $table1
     *
     * @return Response
     */
    public function show(Table1Request $request, Table1 $table1)
    {

        if ($table1->exists) {
            $view = 'teszt::table1.show';
        } else {
            $view = 'teszt::table1.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('teszt::table1.name'))
            ->data(compact('table1'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new table1.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(Table1Request $request)
    {

        $table1 = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('teszt::table1.name')) 
            ->view('teszt::table1.create', true) 
            ->data(compact('table1'))
            ->output();
    }

    /**
     * Create new table1.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(Table1Request $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $table1                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('teszt::table1.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('teszt/table1/' . $table1->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/teszt/table1'))
                ->redirect();
        }

    }

    /**
     * Show table1 for editing.
     *
     * @param Request $request
     * @param Model   $table1
     *
     * @return Response
     */
    public function edit(Table1Request $request, Table1 $table1)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('teszt::table1.name'))
            ->view('teszt::table1.edit', true)
            ->data(compact('table1'))
            ->output();
    }

    /**
     * Update the table1.
     *
     * @param Request $request
     * @param Model   $table1
     *
     * @return Response
     */
    public function update(Table1Request $request, Table1 $table1)
    {
        try {
            $attributes = $request->all();

            $table1->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('teszt::table1.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('teszt/table1/' . $table1->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('teszt/table1/' . $table1->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the table1.
     *
     * @param Model   $table1
     *
     * @return Response
     */
    public function destroy(Table1Request $request, Table1 $table1)
    {
        try {

            $table1->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('teszt::table1.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('teszt/table1/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('teszt/table1/' . $table1->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple table1.
     *
     * @param Model   $table1
     *
     * @return Response
     */
    public function delete(Table1Request $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('teszt::table1.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('teszt/table1'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/teszt/table1'))
                ->redirect();
        }

    }

    /**
     * Restore deleted table1s.
     *
     * @param Model   $table1
     *
     * @return Response
     */
    public function restore(Table1Request $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('teszt::table1.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/teszt/table1'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/teszt/table1/'))
                ->redirect();
        }

    }

}
