<?php

namespace Me\Teszt\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Me\Teszt\Http\Requests\Table1Request;
use Me\Teszt\Models\Table1;

/**
 * Admin web controller class.
 */
class Table1WorkflowController extends BaseController
{

    /**
     * Workflow controller function for table1.
     *
     * @param Model   $table1
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(Table1Request $request, Table1 $table1, $step)
    {

        try {

            $table1->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('teszt::table1.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/table1/table1/' . $table1->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/table1/table1/' . $table1->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for table1.
     *
     * @param Model   $table1
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Table1 $table1, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $table1->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('teszt::table1.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('teszt::admin.table1.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('teszt::admin.table1.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('teszt::admin.table1.message', $data)->render();

        }

    }
}
