<?php

namespace Me\Teszt\Providers;

use Illuminate\Support\ServiceProvider;

class TesztServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'teszt');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'teszt');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerTeszt();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerTeszt()
    {
        $this->app->bind('teszt', function($app) {
            return new Teszt($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Teszt', 'Lavalite\Teszt\Facades\Teszt');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('me.teszt', function ($app) {
            return $this->app->make('Me\Teszt\Teszt');
        });

                // Bind Table1 to repository
        $this->app->bind(
            'Me\Teszt\Interfaces\Table1RepositoryInterface',
            \Me\Teszt\Repositories\Eloquent\Table1Repository::class
        );

        $this->app->register(\Me\Teszt\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Me\Teszt\Providers\RouteServiceProvider::class);
                $this->app->register(\Me\Teszt\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and teszt's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/teszt.php', 'teszt'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeTeszt::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['me.teszt'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('me/teszt.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/teszt')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/teszt')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
