<?php

namespace Me\Teszt\Workflow;

use Me\Teszt\Models\Table1;
use Validator;

class Table1Validator
{

    /**
     * Determine if the given table1 is valid for complete status.
     *
     * @param Table1 $table1
     *
     * @return bool / Validator
     */
    public function complete(Table1 $table1)
    {
        return Validator::make($table1->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given table1 is valid for verify status.
     *
     * @param Table1 $table1
     *
     * @return bool / Validator
     */
    public function verify(Table1 $table1)
    {
        return Validator::make($table1->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given table1 is valid for approve status.
     *
     * @param Table1 $table1
     *
     * @return bool / Validator
     */
    public function approve(Table1 $table1)
    {
        return Validator::make($table1->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given table1 is valid for publish status.
     *
     * @param Table1 $table1
     *
     * @return bool / Validator
     */
    public function publish(Table1 $table1)
    {
        return Validator::make($table1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given table1 is valid for archive status.
     *
     * @param Table1 $table1
     *
     * @return bool / Validator
     */
    public function archive(Table1 $table1)
    {
        return Validator::make($table1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given table1 is valid for unpublish status.
     *
     * @param Table1 $table1
     *
     * @return bool / Validator
     */
    public function unpublish(Table1 $table1)
    {
        return Validator::make($table1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
